#
# spec file for package matio
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           matio
%define libname lib%{name}
Version:        1.5.2
Release:        11.4
%define major   2
Summary:        Open-source library for reading and writing MATLAB MAT files
License:        BSD-2-Clause
Group:          System/Libraries
Url:            http://sourceforge.net/projects/matio
Source0:        http://downloads.sourceforge.net/matio/%{name}-%{version}.tar.gz
BuildRequires:  hdf5-devel >= 1.8
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel >= 1.2.3
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
matio is an open-source library for reading and writing MATLAB MAT files.
This library is designed for use by programs/libraries that do not have
access or do not want to rely on MATLAB's shared library.

%package -n %{libname}%{major}
Summary:        Open-source library for reading and writing MATLAB MAT files
Group:          System/Libraries
# Avoid unresolvable errors from multiple providers
Requires:       libhdf5

%description -n %{libname}%{major}
matio is an open-source library for reading and writing MATLAB MAT files.
This library is designed for use by programs/libraries that do not have
access or do not want to rely on MATLAB's shared library.

%package -n %{libname}-devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{major} = %{version}
Requires:       hdf5-devel
Requires:       pkgconfig
Requires:       zlib-devel

%description -n %{libname}-devel
matio is an open-source library for reading and writing MATLAB MAT files.
This library is designed for use by programs/libraries that do not have
access or do not want to rely on MATLAB's shared library.

%package tools
Summary:        Command line tools for %{name}
Group:          Productivity/Scientific/Other
Requires:       %{libname}%{major} = %{version}
# Avoid unresolvable errors from multiple providers
Requires:       libhdf5

%description tools
matio is an open-source library for reading and writing MATLAB MAT files.
This library is designed for use by programs/libraries that do not have
access or do not want to rely on MATLAB's shared library.

%prep
%setup -q

%build
%configure \
  --enable-shared \
  --disable-static \
  --enable-mat73=yes \
  --enable-extended-sparse=yes

# remove rpath from libtool
sed -i.rpath 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i.rpath 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

make %{?_smp_mflags}

%install
%makeinstall
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print

%check
export LD_LIBRARY_PATH=%{_buildroot}/%{name}*/src/.libs/
make check

%clean
rm -rf %{buildroot}

%post   -n %{libname}%{major} -p /sbin/ldconfig
%postun -n %{libname}%{major} -p /sbin/ldconfig

%files -n %{libname}%{major}
%defattr(-,root,root)
%doc COPYING NEWS README
%{_libdir}/libmatio.so.%{major}*

%files tools
%defattr(-,root,root)
%{_bindir}/matdump

%files -n %{libname}-devel
%defattr(-,root,root)
%{_includedir}/matio.h
%{_includedir}/matio_pubconf.h
%{_libdir}/libmatio.so
%{_libdir}/pkgconfig/matio.pc
%{_mandir}/man3/Mat_*.3.*

%changelog
* Mon Aug 31 2015 toddrme2178@gmail.com
- Avoid unresolvable errors from multiple providers of libhdf5
* Thu Aug  1 2013 dmitry_r@opensuse.org
- Update to version 1.5.2
  * Added support for linear data read for v4 and HDF5 MAT files
  * Fixed bug reading slices of variables in matdump
  * Fix feof calls so they compile on platforms that dereference
  the argument in a macro
  * More robust checking that file is MAT file and eliminates some
  segmentation faults
  * Various fixes for unused variables, unnecessary initializations,
  etc. that cause compilers to issue diagnostices
  * Several other fixes
* Sun Mar 10 2013 dmitry_r@opensuse.org
- Update to version 1.5.1
  * Fix bug writing compressed HDF5 files
  * Fix bug reading cell array elements written with a non-empty
    variable name
  * Fix bug writing complex sparse matrices as struct fields or
    cell elements to uncompressed v5 MAT files
  * Fix a number of potential issues identified via static analysis
  * Fix uninitialized pointers when creating structures through
    Mat_VarCreateStruct, and fix a bug in the struct API testsuite
  * Fix extended sparse support in v7.3 MAT files and add 64-bit
    integer support for v5 MAT files
  * Add missing support for reading hyperslabs from HDF5 MAT files
  * Added variable indexing notation support to matdump to display
    subsets of variables
  * Added tests for extended sparse support in testsuite
  * Add missing enumerations or default case in switch statements
  * removed obsolete gcc-warnings-fix.patch
  * removed obsolete matvar_struct.patch
  * removed obsolete mat4_bigendian.patch
* Thu Dec 20 2012 dvaleev@suse.com
- Fix Big Endian issues in mat4. (mat4_bigendian.patch)
* Thu Dec 20 2012 dvaleev@suse.com
- Fix failing 684 686 test (matvar_struct.patch)
* Fri Aug 17 2012 toddrme2178@gmail.com
- Various spec file cleanups
* Thu Aug 16 2012 dmitry_r@opensuse.org
- update to version 1.5.0
  * Support for reading/writing HDF5 format MAT files
  * Bug fixes for compressed variables that caused issues with
  matio reading them.
  * Upgrade of dimensions in matvar_t structure to size_t enabling
  support for large arrays.
  * A testsuite
- add gcc-warnings-fix.patch: fix implicit declaration
- remove libmatio0-1.3.3-doxygen.patch: now matio doesn't use
  doxygen
* Wed Jun 27 2012 scorot@free.fr
- fix documentation build thanks to a patch from debian
- spec file reformating and cleanup
